﻿using MindFusion.Diagramming;
using MindFusion.Drawing;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace StressTest
{
	// Learn more about making custom code visible in the Xamarin.Forms previewer
	// by visiting https://aka.ms/xamarinforms-previewer
	[DesignTimeVisible(false)]
	public partial class MainPage : ContentPage
	{
		public MainPage()
		{
			InitializeComponent();

			diagram = diagramView.Diagram;
			diagram.LinkSelected += OnLinkSelected;
			diagram.LinkDeselected += OnLinkDeselected;
		}
		private void OnGenerateClick(object sender, EventArgs e)
		{
			DateTime start = DateTime.Now;

			var r = new Random();

			// adding items is slower when the diagram is shown inside a view
			// so we create a new diagram here
			diagram.ClearAll();
			diagram.DefaultShape = Shapes.Rectangle;
			diagram.LinkHeadShape = ArrowHeads.None;

			// adding a lot of items is faster when these properties are set to false
			diagram.ValidityChecks = false;
			diagram.SelectAfterCreate = false;

			// this shows the new link router implemented in version 5.3
			var router = new QuickRouter(diagram);
			router.Granularity = Granularity.CoarseGrained;
			diagram.LinkRouter = router;

			int nodes = 500;
			int links = 1000;
			try
			{
				nodes = int.Parse(tbNodes.Text);
				links = int.Parse(tbLinks.Text);
			}
			catch
			{
			}

			for (int i = 0; i < nodes; ++i)
			{
				diagram.Factory.CreateShapeNode(r.Next(1000), r.Next(1000), 20, 10);
			}

			for (int i = 0; i < links; ++i)
			{
				diagram.Factory.CreateDiagramLink(
					diagram.Nodes[r.Next(nodes - 1)],
					diagram.Nodes[r.Next(nodes - 1)]);
			}

			if (cbRouteLinks.IsToggled)
				diagram.RouteAllLinks();

			TimeSpan ellapsed = DateTime.Now - start;
			lbTimeEllapsed.Text = ellapsed.ToString();

			// finally show the diagram inside the view
			diagram.Bounds = new Rectangle(0, 0, 1050, 1050);
		}

		private void OnLinkSelected(object sender, MindFusion.Diagramming.LinkEventArgs e)
		{
			e.Link.Pen = new Pen(Color.Green, 1);
		}

		private void OnLinkDeselected(object sender, MindFusion.Diagramming.LinkEventArgs e)
		{
			e.Link.Pen = new Pen(Color.Black, 0);
		}

		Diagram diagram;
	}
}
